@@ -25,7 +25,7 @@ class FreetypeRecipe(Recipe):
     """
 
     version = '2.10.1'
-    url = 'http://download.savannah.gnu.org/releases/freetype/freetype-{version}.tar.gz'  # noqa
+    url = 'https://download.savannah.gnu.org/releases/freetype/freetype-{version}.tar.gz'  # noqa
     built_libraries = {'libfreetype.so': 'objs/.libs'}
 
     def get_recipe_env(self, arch=None, with_harfbuzz=False):
@@ -47,8 +47,8 @@ class FreetypeRecipe(Recipe):
             )
 
         # android's zlib support
-        zlib_lib_path = arch.ndk_lib_dir
-        zlib_includes = self.ctx.ndk_include_dir
+        zlib_lib_path = arch.ndk_lib_dir_versioned
+        zlib_includes = self.ctx.ndk.sysroot_include_dir
 
         def add_flag_if_not_added(flag, env_key):
             if flag not in env[env_key]:
