@@ -15,7 +15,7 @@ class Kivy3Recipe(PythonRecipe):
     def build_arch(self, arch):
         super().build_arch(arch)
         suffix = '/kivy3/default.glsl'
-        shutil.copyfile(self.get_build_dir(arch.arch) + suffix, self.ctx.get_python_install_dir() + suffix)
+        shutil.copyfile(self.get_build_dir(arch.arch) + suffix, self.ctx.get_python_install_dir(arch.arch) + suffix)
 
 
 recipe = Kivy3Recipe()
