@@ -2,11 +2,14 @@
     android libglob
     available via '-lglob' LDFLAG
 """
-from os.path import exists, join
+from os.path import join
+
+import sh
+
+from pythonforandroid.logger import shprint
 from pythonforandroid.recipe import Recipe
 from pythonforandroid.toolchain import current_directory
-from pythonforandroid.logger import info, shprint
-import sh
+from pythonforandroid.util import ensure_dir
 
 
 class LibGlobRecipe(Recipe):
@@ -32,9 +35,7 @@ class LibGlobRecipe(Recipe):
     def prebuild_arch(self, arch):
         """Make the build and target directories"""
         path = self.get_build_dir(arch.arch)
-        if not exists(path):
-            info("creating {}".format(path))
-            shprint(sh.mkdir, '-p', path)
+        ensure_dir(path)
 
     def build_arch(self, arch):
         """simple shared compile"""
@@ -43,9 +44,7 @@ class LibGlobRecipe(Recipe):
                 self.get_build_dir(arch.arch),
                 join(self.ctx.python_recipe.get_build_dir(arch.arch), 'Lib'),
                 join(self.ctx.python_recipe.get_build_dir(arch.arch), 'Include')):
-            if not exists(path):
-                info("creating {}".format(path))
-                shprint(sh.mkdir, '-p', path)
+            ensure_dir(path)
         cli = env['CC'].split()[0]
         # makes sure first CC command is the compiler rather than ccache, refs:
         # https://github.com/kivy/python-for-android/issues/1399
