@@ -1,9 +1,12 @@
-from pythonforandroid.toolchain import Recipe, shprint, shutil, current_directory
 from multiprocessing import cpu_count
-from os.path import join, basename
 from os import listdir, walk
+from os.path import join, basename
+import shutil
+
 import sh
 
+from pythonforandroid.toolchain import Recipe, shprint, current_directory
+
 # This recipe builds libtorrent with Python bindings
 # It depends on Boost.Build and the source of several Boost libraries present
 # in BOOST_ROOT, which is all provided by the boost recipe
@@ -132,7 +135,7 @@ class LibtorrentRecipe(Recipe):
 
         python_libtorrent = get_lib_from(join(build_dir, 'bindings/python/bin'))
         shutil.copyfile(python_libtorrent,
-                        join(self.ctx.get_site_packages_dir(arch.arch), 'libtorrent.so'))
+                        join(self.ctx.get_site_packages_dir(arch), 'libtorrent.so'))
 
     def get_recipe_env(self, arch):
         # Use environment from boost recipe, cause we use b2 tool from boost
